package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.DeviceMapper;
import com.datacloudsec.scan.dao.HostscanMapper;
import com.datacloudsec.scan.dao.KeywordTempMapper;
import com.datacloudsec.scan.dao.SysconfigMapper;
import com.datacloudsec.scan.dao.SysscanInfoMapper;
import com.datacloudsec.scan.dao.SystemTempMapper;
import com.datacloudsec.scan.dao.TaskBaseMapper;
import com.datacloudsec.scan.entity.LicCmp;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IBaseline;
import com.datacloudsec.scan.service.IDb;
import com.datacloudsec.scan.service.IDevice;
import com.datacloudsec.scan.service.IHostscan;
import com.datacloudsec.scan.service.ITask;
import com.datacloudsec.scan.service.IWeb;
import com.datacloudsec.scan.tasks.InitSystemTask;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.IPUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.ObjectUtil;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/HostscanService.class */
public class HostscanService implements IHostscan {
    private HostscanMapper hostscanMapper = (HostscanMapper) InstanceUtil.newDaoInstance(HostscanMapper.class);
    private ITask taskService = (ITask) InstanceUtil.newServiceInstance(TaskService.class);
    private IDb dbService = (IDb) InstanceUtil.newServiceInstance(DbService.class);
    private IBaseline baselineService = (IBaseline) InstanceUtil.newServiceInstance(BaselineService.class);
    private IWeb webService = (IWeb) InstanceUtil.newServiceInstance(WebService.class);
    private TaskBaseMapper taskBaseMapper = (TaskBaseMapper) InstanceUtil.newDaoInstance(TaskBaseMapper.class);
    private DeviceMapper deviceMapper = (DeviceMapper) InstanceUtil.newDaoInstance(DeviceMapper.class);
    private SysscanInfoMapper sysscanInfo = (SysscanInfoMapper) InstanceUtil.newDaoInstance(SysscanInfoMapper.class);
    private SystemTempMapper systemTempMapper = (SystemTempMapper) InstanceUtil.newDaoInstance(SystemTempMapper.class);
    private SysconfigMapper sysconfigMapper = (SysconfigMapper) InstanceUtil.newDaoInstance(SysconfigMapper.class);
    private KeywordTempMapper keywordTemp = (KeywordTempMapper) InstanceUtil.newDaoInstance(KeywordTempMapper.class);

    public int searchCount(HttpSession session, String name, Integer status) throws Exception {
        return this.hostscanMapper.searchCount(name, status, DataRule.getRuleWhere(session, "t_task"));
    }

    public List<Map<String, Object>> search(HttpSession session, String name, Integer status, Integer offset, Integer limit) throws Exception {
        return this.hostscanMapper.search(name, status, offset, limit, DataRule.getRuleWhere(session, "t_task"));
    }

    @Transactional
    public Integer insert(HttpSession session, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String devList, String periodTime, String emailcheck, String smscheck, String warningType, Integer val1, String hostIps, String webUrls) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        if (!cmp.contains("sysscan")) {
            throw new UEException("系统任务未授权");
        }
        LicCmp licCmp = getLicCp(cmp, "sysscan");
        if (InitSystemTask.licenseApp.valudate(licCmp.getAuthDay()) != 0) {
            throw new UEException("系统任务授权已过期");
        }
        try {
            Integer uid = ((User) session.getAttribute("userInfo")).getId();
            Integer count = this.taskBaseMapper.getTaskCountByName(name, 11, uid, (Integer) null);
            if (count != null && count.intValue() > 0) {
                throw new UEException("任务名称已存在！");
            }
        } catch (Exception e) {
            Integer count2 = this.taskBaseMapper.getTcountForOthers(name, 11, (Integer) null);
            if (count2 != null && count2.intValue() > 0) {
                throw new UEException("任务名称已存在！");
            }
        }
        return add(null, name, desct, type, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, devList, periodTime, emailcheck, smscheck, null, 11, warningType, val1, hostIps, webUrls, session);
    }

    private Integer add(Integer id, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String devList, String periodTime, String emailcheck, String smscheck, Integer version, Integer taskType, String warningType, Integer val1, String hostIps, String webUrls, HttpSession session) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "hostscan");
        int maxdevice = licCmp.getMaxdevice();
        User user = (User) session.getAttribute("userInfo");
        String rule = DataRule.getRuleWhere(session, "t_task");
        Task task = new Task();
        task.setName(name);
        task.setDesct(desct);
        task.setType(type);
        task.setAlarmMethod(alarmMethod);
        task.setAlarmType(alarmType);
        task.setAlarmTime(alarmTime);
        task.setMailAddr(emailcheck);
        task.setSmsAddr(smscheck);
        task.setPeriodTime(periodTime);
        if (user != null) {
            task.setUid(user.getId());
        }
        task.setTaskType(taskType);
        task.setVersion(version);
        task.setRule(rule);
        task.setWarningType(warningType);
        task.setVal1(val1);
        task.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        task.setVal3(hostIps);
        if (StringUtils.isNotBlank(webUrls)) {
            task.setConfContent(JsonUtil.MAPPER.writeValueAsString(webUrls.split("\n")));
        }
        if (id != null) {
            task.setId(id);
        }
        if (id == null) {
            List<Map<String, Object>> devListMap = null;
            int ipCount = 0;
            if (StringUtils.isNotBlank(devList)) {
                devListMap = (List) JsonUtil.MAPPER_ESCAPE_HTML.readValue(devList, ArrayList.class);
                ipCount = checkDevIp(devListMap, user);
            }
            if (StringUtils.isNotBlank(hostIps)) {
                ipCount = checkSysIp(hostIps, user);
            }
            if (StringUtils.isNotBlank(webUrls)) {
                ipCount = checkWebIp(webUrls, user);
            }
            if (maxdevice > 0 && this.deviceMapper.getDevRecord("hostscan").intValue() + ipCount > maxdevice) {
                throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
            }
            this.taskBaseMapper.insert(task);
            if (CollectionUtils.isNotEmpty(devListMap)) {
                Map<String, List<Map<String, Object>>> devLists = new HashMap<>();
                for (Map<String, Object> devMap : devListMap) {
                    int devid = ObjectUtil.getInt(devMap.get("id")).intValue();
                    Map<? extends String, ? extends Object> map = this.deviceMapper.getDevById(Integer.valueOf(devid));
                    if (map != null) {
                        Map<String, Object> confContentMap = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(map.get("confContent"), ""), HashMap.class);
                        Map<String, Object> authContentMap = null;
                        String authConf = ObjectUtil.getString(map.get("authContent"), "");
                        if (StringUtils.isNotBlank(authConf)) {
                            authContentMap = (Map) JsonUtil.MAPPER.readValue(authConf, HashMap.class);
                        }
                        for (Map.Entry<String, Object> e : confContentMap.entrySet()) {
                            String mkey = e.getKey();
                            List<Map<String, Object>> list = devLists.get(mkey);
                            if (list == null) {
                                list = new ArrayList<>();
                                devLists.put(mkey, list);
                            }
                            if (e.getValue() instanceof Map) {
                                Map<String, Object> dev = new HashMap<>();
                                dev.putAll(map);
                                dev.put("confContent", e.getValue());
                                if (authContentMap != null) {
                                    dev.put("authContent", authContentMap);
                                }
                                list.add(dev);
                            } else if (e.getValue() instanceof List) {
                                List<Map<String, Object>> vList = (List) e.getValue();
                                List<Map<String, Object>> devlist = new ArrayList<>();
                                for (Map<String, Object> m : vList) {
                                    Map<String, Object> dev2 = new HashMap<>();
                                    dev2.putAll(map);
                                    dev2.put("confContent", m);
                                    if (authContentMap != null) {
                                        dev2.put("authContent", authContentMap);
                                    }
                                    devlist.add(dev2);
                                }
                                list.addAll(devlist);
                            }
                        }
                    }
                }
                for (Map.Entry<String, List<Map<String, Object>>> e2 : devLists.entrySet()) {
                    Integer devType = ObjectUtil.getInt(e2.getKey());
                    List<Map<String, Object>> list2 = e2.getValue();
                    switch (devType.intValue()) {
                        case 0:
                            addSys(task, list2);
                            addBline(task, list2, devType.intValue());
                            break;
                        case 1:
                            addWeb(task, list2);
                            break;
                        case 2:
                            addDb(task, list2);
                            addBline(task, list2, devType.intValue());
                            break;
                        case 3:
                        case 4:
                        case 5:
                        case 6:
                        case 11:
                            addBline(task, list2, devType.intValue());
                            break;
                    }
                }
            }
            if (StringUtils.isNotBlank(hostIps)) {
                addSysByIps(task, hostIps);
            }
            if (StringUtils.isNotBlank(webUrls)) {
                addWebByUrls(task, webUrls, user);
            }
        } else {
            Integer rcount = this.taskBaseMapper.update(task);
            if (rcount != null && rcount.intValue() == 0) {
                throw new UEException("数据已被修改或删除，请刷新页面或返回");
            }
        }
        if (user != null) {
            if (StringUtils.isNotBlank(mailAddr)) {
                this.taskBaseMapper.delEmail(user.getId());
                String[] mail = mailAddr.split(",");
                for (String ml : mail) {
                    this.taskBaseMapper.insertEmail(ml, user.getId());
                }
            }
            if (StringUtils.isNotBlank(smsAddr)) {
                this.taskBaseMapper.delPhone(user.getId());
                String[] sms = smsAddr.split(",");
                for (String s : sms) {
                    this.taskBaseMapper.insertPhone(s, user.getId());
                }
            }
        }
        return task.getId();
    }

    private int checkDevIp(List<Map<String, Object>> devListMap, User user) throws Exception {
        String ip;
        int devIpCount = 0;
        for (Map<String, Object> devMap : devListMap) {
            if (devMap != null) {
                if (devMap.size() == 1) {
                    ip = ObjectUtil.getString(devMap.get("ip"), "");
                } else {
                    String[] idarr = ObjectUtil.getString(devMap.get("id"), "").split("\\|");
                    Map<String, Object> map = this.deviceMapper.getDevById(ObjectUtil.getInt(idarr[0]));
                    if (map == null) {
                        continue;
                    } else {
                        ip = ObjectUtil.getString(map.get("ip"), "");
                    }
                }
                if (user != null && StringUtils.isNotBlank(user.getIps()) && !IPUtil.ipVaild(ip, user.getIps())) {
                    throw new UEException("IP【" + ip + "】不在扫描范围内，可联系管理员授权扫描此IP");
                }
                if (this.deviceMapper.getDevRecordByIp(ip, "hostscan").intValue() == 0) {
                    devIpCount++;
                }
            }
        }
        return devIpCount;
    }

    private int checkSysIp(String hostIps, User user) throws Exception {
        int devIpCount = 0;
        if (user != null) {
            for (String ip : hostIps.split("\n")) {
                if (ip.contains("*")) {
                    devIpCount += 254;
                    if (StringUtils.isNotBlank(user.getIps())) {
                        for (int i = 1; i <= 255; i++) {
                            String iptemp = ip.substring(0, ip.lastIndexOf("*"));
                            if (!IPUtil.ipVaild(String.valueOf(iptemp) + i, user.getIps())) {
                                throw new UEException("IP【" + ip + "】不在扫描范围内，可联系管理员授权扫描此IP");
                            }
                        }
                    } else {
                        continue;
                    }
                } else if (ip.contains("-")) {
                    String[] ipTmp = ip.split("-");
                    if (ipTmp[1].contains(".")) {
                        devIpCount += ObjectUtil.getInt(Long.valueOf(IPUtil.ipToLong(ipTmp[1]) - IPUtil.ipToLong(ipTmp[0])), 0);
                    } else {
                        devIpCount += ObjectUtil.getInt(Long.valueOf(IPUtil.ipToLong(String.valueOf(ipTmp[0].substring(0, ipTmp[0].lastIndexOf(".") + 1)) + ipTmp[1]) - IPUtil.ipToLong(ipTmp[0])), 0);
                        if (StringUtils.isNotBlank(user.getIps())) {
                            String iptemp2 = ip.substring(0, ip.lastIndexOf(".") + 1);
                            int start = ObjectUtil.getInt(ipTmp[0].substring(ipTmp[0].lastIndexOf(".") + 1, ipTmp[0].length()), 0);
                            for (int i2 = start; i2 < ObjectUtil.getInt(ipTmp[1], 0); i2++) {
                                if (!IPUtil.ipVaild(String.valueOf(iptemp2) + i2, user.getIps())) {
                                    throw new UEException("IP【" + ip + "】不在扫描范围内，可联系管理员授权扫描此IP");
                                }
                            }
                        } else {
                            continue;
                        }
                    }
                } else if (ip.contains("/")) {
                    devIpCount += ObjectUtil.getInt(Double.valueOf(Math.pow(2.0d, 32.0d - ObjectUtil.getDouble(ip.split("/")[1], 0.0d)) - 2.0d), 0);
                } else {
                    if (this.deviceMapper.getDevRecordByIp(ip, "hostscan").intValue() == 0) {
                        devIpCount++;
                    }
                    if (StringUtils.isNotBlank(user.getIps()) && !IPUtil.ipVaild(ip, user.getIps())) {
                        throw new UEException("IP【" + ip + "】不在扫描范围内，可联系管理员授权扫描此IP");
                    }
                }
            }
        }
        return devIpCount;
    }

    private int checkWebIp(String webUrls, User user) throws Exception {
        int devIpCount = 0;
        for (String str : webUrls.split("\n")) {
            String url = IPUtil.urlFormat(str);
            if (this.deviceMapper.getDevRecordByIp(IPUtil.urlFormat(url), "webscan").intValue() == 0) {
                devIpCount++;
            }
            if (user != null && StringUtils.isNotBlank(user.getUrls()) && !Arrays.asList(user.getUrls().split("\n")).contains(url)) {
                throw new UEException("网站地址【" + url + "】不在扫描范围内，可联系管理员授权扫描此IP");
            }
        }
        return devIpCount;
    }

    private void addSys(Task task, List<Map<String, Object>> list) throws Exception {
        Map<String, Object> portMap = new HashMap<>();
        portMap.put("ssh", 22);
        portMap.put("telnet", 23);
        portMap.put("smb", 445);
        portMap.put("winrm", 5986);
        Map<String, Object> systemp = this.systemTempMapper.getTempByName("全部");
        Map<String, Object> sysconfig = this.sysconfigMapper.getConfigByName("系统默认");
        for (Map<String, Object> map : list) {
            Task sys = new Task();
            sys.setName(task.getName());
            sys.setType(task.getType());
            sys.setAlarmMethod(task.getAlarmMethod());
            sys.setAlarmTime(task.getAlarmTime());
            sys.setAlarmType(task.getAlarmType());
            sys.setPeriodTime(task.getPeriodTime());
            sys.setMailAddr(task.getMailAddr());
            sys.setSmsAddr(task.getSmsAddr());
            sys.setHostId(task.getId());
            sys.setTaskType(1);
            sys.setWarningType("high,medium");
            sys.setConfContent(JsonUtil.MAPPER.writeValueAsString(defaultConf("系统")));
            sys.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
            sys.setVal3("[{\"name\":\"" + ObjectUtil.getString(map.get("ip"), "") + "\"}]");
            sys.setSysId(ObjectUtil.getInt(systemp.get("id")));
            sys.setSysconfigId(ObjectUtil.getInt(sysconfig.get("id")));
            sys.setUid(task.getUid());
            this.taskBaseMapper.insert(sys);
            Map<String, Object> confMap = (Map) map.get("confContent");
            if (confMap != null && confMap.size() > 0) {
                Map<String, Object> authMap = (Map) map.get("authContent");
                if (authMap != null && authMap.size() > 0) {
                    confMap.putAll(authMap);
                }
                confMap.put("ip", ObjectUtil.getString(map.get("ip"), ""));
                confMap.put("id", ObjectUtil.getInt(map.get("id")));
                if (ObjectUtil.getInt(confMap.get("port")) == null) {
                    confMap.put("port", portMap.get(ObjectUtil.getString(confMap.get("protocol"), "")));
                }
                this.sysscanInfo.setValue("sysscan_auth_" + sys.getId(), JsonUtil.MAPPER.writeValueAsString(confMap));
            }
            this.sysscanInfo.setValue("sysscan_ip_" + sys.getId(), ObjectUtil.getString(map.get("ip"), ""));
        }
    }

    private void addSysByIps(Task task, String hostIps) throws Exception {
        if (StringUtils.isBlank(hostIps)) {
            return;
        }
        Task sys = new Task();
        sys.setName(task.getName());
        sys.setType(task.getType());
        sys.setAlarmMethod(task.getAlarmMethod());
        sys.setAlarmTime(task.getAlarmTime());
        sys.setAlarmType(task.getAlarmType());
        sys.setPeriodTime(task.getPeriodTime());
        sys.setMailAddr(task.getMailAddr());
        sys.setSmsAddr(task.getSmsAddr());
        sys.setHostId(task.getId());
        sys.setTaskType(1);
        sys.setWarningType("high,medium");
        sys.setConfContent(JsonUtil.MAPPER.writeValueAsString(defaultConf("系统")));
        sys.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        if (StringUtils.isNotBlank(hostIps)) {
            List<Map<String, Object>> ipList = new ArrayList<>();
            for (String ip : hostIps.split("\n")) {
                Map<String, Object> ipMap = new HashMap<>();
                ipMap.put("name", ip);
                ipList.add(ipMap);
            }
            sys.setVal3(JsonUtil.MAPPER.writeValueAsString(ipList));
        }
        sys.setSysId(ObjectUtil.getInt(this.systemTempMapper.getTempByName("全部").get("id")));
        sys.setSysconfigId(ObjectUtil.getInt(this.sysconfigMapper.getConfigByName("系统默认").get("id")));
        sys.setUid(task.getUid());
        this.taskBaseMapper.insert(sys);
        this.sysscanInfo.setValue("sysscan_ip_" + sys.getId(), hostIps.replace("\n", ";"));
    }

    private void addWeb(Task task, List<Map<String, Object>> list) throws Exception {
        Map<String, Object> keyword = this.keywordTemp.getIdByName("系统默认", "1=1");
        for (Map<String, Object> map : list) {
            Task web = new Task();
            web.setName(task.getName());
            web.setType(task.getType());
            web.setAlarmMethod(task.getAlarmMethod());
            web.setAlarmTime(task.getAlarmTime());
            web.setAlarmType(task.getAlarmType());
            web.setPeriodTime(task.getPeriodTime());
            web.setMailAddr(task.getMailAddr());
            web.setSmsAddr(task.getSmsAddr());
            web.setHostId(task.getId());
            web.setTaskType(0);
            web.setWarningType("high,medium,low,avail");
            web.setDest("bug,horse,keyword,tamper,avail,fish");
            web.setTamper("imgMD5,title,delLinkRemind,newLinkRemind");
            web.setKid(ObjectUtil.getInt(keyword.get("id")));
            web.setSimilarity(95);
            web.setHiddenLinkCheckDepth(1);
            web.setKeyset("img,idCard");
            web.setConfContent(JsonUtil.MAPPER.writeValueAsString(defaultConf("网站")));
            web.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
            web.setUid(task.getUid());
            this.taskBaseMapper.insert(web);
            map.put("type", 1);
            map.put("taskId", web.getId());
            map.put("hostId", web.getHostId());
            map.put("did", ObjectUtil.getInt(map.get("id")));
            Map<String, Object> webConfig = (Map) map.get("confContent");
            String url = IPUtil.urlFormat(ObjectUtil.getString(webConfig.get("url"), ""));
            webConfig.put("whiteList", IPUtil.urlFormat(ObjectUtil.getString(webConfig.get("whiteList"), "")));
            webConfig.put("url", url);
            map.put("confContent", JsonUtil.MAPPER.writeValueAsString(webConfig));
            map.put("name", String.valueOf(url) + "【网站】");
            this.taskBaseMapper.insertTaskDevice(map);
        }
    }

    private void addWebByUrls(Task task, String webUrls, User user) throws Exception {
        if (StringUtils.isBlank(webUrls)) {
            return;
        }
        Map<String, Object> keyword = this.keywordTemp.getIdByName("系统默认", "1=1");
        for (String webUrl : webUrls.split("\n")) {
            Task web = new Task();
            web.setName(task.getName());
            web.setType(task.getType());
            web.setAlarmMethod(task.getAlarmMethod());
            web.setAlarmTime(task.getAlarmTime());
            web.setAlarmType(task.getAlarmType());
            web.setPeriodTime(task.getPeriodTime());
            web.setMailAddr(task.getMailAddr());
            web.setSmsAddr(task.getSmsAddr());
            web.setHostId(task.getId());
            web.setTaskType(0);
            web.setWarningType("high,medium,low,avail");
            web.setDest("bug,horse,keyword,tamper,avail,fish");
            web.setTamper("imgMD5,title,delLinkRemind,newLinkRemind");
            web.setKid(ObjectUtil.getInt(keyword.get("id")));
            web.setSimilarity(95);
            web.setHiddenLinkCheckDepth(1);
            web.setKeyset("img,idCard");
            web.setConfContent(JsonUtil.MAPPER.writeValueAsString(defaultConf("网站")));
            web.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
            web.setUid(task.getUid());
            this.taskBaseMapper.insert(web);
            Map<String, Object> dmap = new HashMap<>();
            String url = IPUtil.urlFormat(webUrl);
            dmap.put("name", String.valueOf(url.length() > 50 ? url.substring(0, 50) : url) + "【网站】");
            dmap.put("type", 1);
            dmap.put("ip", "");
            dmap.put("taskId", web.getId());
            dmap.put("hostId", web.getHostId());
            dmap.put("regionSid", Integer.valueOf((user == null || user.getRegionSid() == null) ? 110000 : user.getRegionSid().intValue()));
            dmap.put("regionCid", Integer.valueOf((user == null || user.getRegionCid() == null) ? 110101 : user.getRegionCid().intValue()));
            dmap.put("confContent", "{\"url\":\"" + url + "\"}");
            this.taskBaseMapper.insertTaskDevice(dmap);
        }
    }

    private void addDb(Task task, List<Map<String, Object>> list) throws Exception {
        for (Map<String, Object> map : list) {
            Task db = new Task();
            db.setName(task.getName());
            db.setType(task.getType());
            db.setAlarmMethod(task.getAlarmMethod());
            db.setAlarmTime(task.getAlarmTime());
            db.setAlarmType(task.getAlarmType());
            db.setPeriodTime(task.getPeriodTime());
            db.setMailAddr(task.getMailAddr());
            db.setSmsAddr(task.getSmsAddr());
            db.setHostId(task.getId());
            db.setTaskType(4);
            db.setWarningType("critical,high,medium");
            db.setConfContent("{\"scanDest\":\"bug\"}");
            db.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
            db.setUid(task.getUid());
            this.taskBaseMapper.insert(db);
            map.put("taskId", db.getId());
            Map<String, Object> confMap = (Map) map.get("confContent");
            map.put("confContent", JsonUtil.MAPPER.writeValueAsString(confMap));
            map.put("type", 2);
            map.put("hostId", db.getHostId());
            map.put("name", String.valueOf(ObjectUtil.getString(map.get("ip"), "")) + " 【数据库】 " + ((String) IDb.DB_SCAN_TYPE.get(new StringBuilder().append(confMap.get("db")).toString())) + " " + confMap.get("port"));
            this.taskBaseMapper.insertTaskDevice(map);
        }
    }

    private void addBline(Task task, List<Map<String, Object>> list, int type) throws Exception {
        Map<String, Object> map;
        Map<String, Object> map2;
        Map<?, ?> blineConf = (Map) JsonUtil.MAPPER.readValue(new File(Constant.CONF_DIR, "blinepolicie/version.json"), Map.class);
        Map<String, Object> blineMmap = new HashMap<>();
        for (Map.Entry<?, ?> e : blineConf.entrySet()) {
            if ("middleware".equalsIgnoreCase((String) e.getKey())) {
                Map<String, Object> mid = (Map) e.getValue();
                for (Map.Entry<String, Object> me : mid.entrySet()) {
                    blineMmap.put(me.getKey(), ((Map) me.getValue()).get("name"));
                }
            } else if (e.getValue() instanceof Map) {
                blineMmap.putAll((Map) e.getValue());
            }
        }
        for (Map<String, Object> map3 : list) {
            if (map3.get("confContent") != null && map3.get("authContent") != null) {
                Task bline = new Task();
                bline.setName(task.getName());
                bline.setType(task.getType());
                bline.setAlarmMethod(task.getAlarmMethod());
                bline.setAlarmTime(task.getAlarmTime());
                bline.setAlarmType(task.getAlarmType());
                bline.setPeriodTime(task.getPeriodTime());
                bline.setMailAddr(task.getMailAddr());
                bline.setSmsAddr(task.getSmsAddr());
                bline.setHostId(task.getId());
                bline.setTaskType(2);
                bline.setWarningType("inconformity");
                bline.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
                bline.setUid(task.getUid());
                bline.setBtype("默认");
                this.taskBaseMapper.insert(bline);
                map3.put("taskId", bline.getId());
                map3.put("hostId", bline.getHostId());
                if (map3.get("confContent") instanceof String) {
                    map = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(map3.get("confContent"), ""), Map.class);
                } else {
                    map = (Map) map3.get("confContent");
                }
                Map<String, Object> confMap = map;
                if (confMap != null) {
                    if (map3.get("authContent") instanceof String) {
                        map2 = StringUtils.isBlank(ObjectUtil.getString(map3.get("authContent"), "")) ? new HashMap<>() : (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(map3.get("authContent"), ""), Map.class);
                    } else {
                        map2 = (Map) map3.get("authContent");
                    }
                    Map<String, Object> authMap = map2;
                    if (MapUtils.isNotEmpty(authMap) && type != 2 && MapUtils.isNotEmpty(authMap)) {
                        confMap.putAll(authMap);
                    }
                    map3.put("confContent", JsonUtil.MAPPER.writeValueAsString(confMap));
                }
                map3.put("type", Integer.valueOf(type == 0 ? 7 : type == 2 ? 8 : type));
                if (type == 2) {
                    map3.put("name", String.valueOf(ObjectUtil.getString(map3.get("ip"), "")) + " 【基线】 " + ((String) IDevice.DEVICE_TYPE.get(new StringBuilder(String.valueOf(type)).toString())) + " " + ((String) IDb.DB_SCAN_TYPE.get(new StringBuilder().append(confMap.get("db")).toString())) + " " + confMap.get("port"));
                } else if (type == 3 || type == 4 || type == 6) {
                    map3.put("name", String.valueOf(ObjectUtil.getString(map3.get("ip"), "")) + " 【基线】 " + ((String) IDevice.DEVICE_TYPE.get(new StringBuilder(String.valueOf(type)).toString())) + " " + blineMmap.get(confMap.get("linuxV")));
                } else {
                    map3.put("name", String.valueOf(ObjectUtil.getString(map3.get("ip"), "")) + " 【基线】 " + ((String) IDevice.DEVICE_TYPE.get(new StringBuilder(String.valueOf(type)).toString())));
                }
                this.taskBaseMapper.insertTaskDevice(map3);
            }
        }
    }

    private Map<String, Object> defaultConf(String type) throws Exception {
        Map<String, Object> conf = com.datacloudsec.scan.cache.Task.getInstance().getConfig();
        List<Map<String, Object>> webList = (List) conf.get(type);
        Map<String, Object> confContents = new HashMap<>();
        for (Map<String, Object> web : webList) {
            if (web.containsKey("childs")) {
                List<Map<String, Object>> valueList = (List) web.get("childs");
                for (Map<String, Object> val : valueList) {
                    String value = ObjectUtil.getString(val.get("value"), "");
                    if ("select".equals(ObjectUtil.getString(val.get("type"), ""))) {
                        confContents.put(ObjectUtil.getString(val.get("name"), ""), value.split("\\|")[0]);
                    } else {
                        confContents.put(ObjectUtil.getString(val.get("name"), ""), value);
                    }
                }
            } else {
                String value2 = ObjectUtil.getString(web.get("value"), "");
                if ("select".equals(ObjectUtil.getString(web.get("type"), ""))) {
                    confContents.put(ObjectUtil.getString(web.get("name"), ""), value2.split("\\|")[0]);
                } else {
                    confContents.put(ObjectUtil.getString(web.get("name"), ""), value2);
                }
            }
        }
        return confContents;
    }

    protected LicCmp getLicCp(String cmps, String cmp) {
        int maxdevice = 5;
        int authDay = 0;
        int maxReq = 0;
        String[] split = cmps.split("/");
        int length = split.length;
        int i = 0;
        while (true) {
            if (i >= length) {
                break;
            }
            String mod = split[i];
            if (!mod.startsWith(cmp)) {
                i++;
            } else {
                String[] modEntry = mod.split(":");
                if (modEntry.length >= 2) {
                    authDay = ObjectUtil.getInt(modEntry[1], 0);
                }
                if (modEntry.length >= 3) {
                    maxdevice = ObjectUtil.getInt(modEntry[2], 5);
                }
                if (modEntry.length >= 4) {
                    maxReq = ObjectUtil.getInt(modEntry[3], 10);
                }
            }
        }
        return new LicCmp(Integer.valueOf(authDay), maxdevice, maxReq);
    }

    public void update(HttpSession session, Integer id, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String periodTime, String emailcheck, String smscheck, Integer version, String warningType, Integer val1, String hostIps, String webUrls) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.taskBaseMapper.getTaskCountByName(name, 11, uid, id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("任务名称已存在！");
        }
        add(id, name, desct, type, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, null, periodTime, emailcheck, smscheck, version, 11, warningType, val1, hostIps, webUrls, session);
        this.hostscanMapper.updVersionByHostid(id);
        this.taskService.stopTimer(session, id);
        if (alarmType.intValue() == 2 || type.intValue() == 2) {
            this.taskService.startTimer(session, id);
        }
    }

    /* JADX WARN: Failed to find 'out' block for switch in B:14:0x0050. Please report as an issue. */
    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        Integer count = this.hostscanMapper.getScaningCountByHostid(id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("任务正在扫描中...");
        }
        List<Task> tasks = this.hostscanMapper.getTaskByHostid(id);
        for (Task t : tasks) {
            try {
                switch (t.getTaskType().intValue()) {
                    case 0:
                        this.webService.delete(session, t.getId(), version);
                    case 1:
                        this.taskService.delete(session, t.getId(), version);
                    case 2:
                        this.baselineService.delete(session, t.getId(), version);
                    case 4:
                        this.dbService.delete(session, t.getId(), version);
                }
            } catch (Exception e) {
                throw new UEException("任务正在扫描中...", e);
            }
        }
        this.taskBaseMapper.delete(id, version, DataRule.getRuleWhere(session, "t_task"));
        new File(Constant.HOSTSCAN_DIC, new StringBuilder().append(id).toString()).delete();
    }

    public void start(Integer devid) throws Exception {
        Map<String, Object> device = this.taskBaseMapper.getTaskDevById(devid);
        int status = ObjectUtil.getInt(device.get("status"), 0);
        if (status == 1) {
            throw new UEException("正在扫描中...");
        }
        Integer type = ObjectUtil.getInt(device.get("type"));
        switch (type.intValue()) {
            case 0:
                throw new UEException("主机任务资产不允许扫描");
            case 1:
                this.webService.start(devid, ObjectUtil.getInt(device.get("taskId")));
                return;
            case 2:
                this.dbService.start(devid);
                return;
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 11:
                this.baselineService.start(devid);
                return;
            case 9:
            case 10:
            default:
                return;
        }
    }

    public void startScanTask(Integer taskId) throws Exception {
        List<Task> tasks = this.hostscanMapper.getTaskByHostid(taskId);
        for (Task t : tasks) {
            switch (t.getTaskType().intValue()) {
                case 0:
                    this.webService.startScanTask(t.getId());
                    break;
                case 1:
                    this.taskService.startTask(t.getId());
                    break;
                case 2:
                    this.baselineService.startScanTask(t.getId());
                    break;
                case 4:
                    this.dbService.startScanTask(t.getId());
                    break;
            }
        }
        this.hostscanMapper.scanCountPlus(taskId);
    }

    public void delDev(HttpSession session, Integer taskId) throws Exception {
        Task task = this.taskBaseMapper.getTaskById(taskId);
        switch (task.getTaskType().intValue()) {
            case 0:
                this.webService.delete(session, taskId, task.getVersion());
                return;
            case 1:
                this.taskService.delete(session, taskId, task.getVersion());
                return;
            case 2:
                this.baselineService.delete(session, taskId, task.getVersion());
                return;
            case 3:
            default:
                return;
            case 4:
                this.dbService.delete(session, taskId, task.getVersion());
                return;
        }
    }

    public File backup(Task t) throws Exception {
        return null;
    }

    public void restore(HttpSession session, File f) throws Exception {
    }

    public void enter(HttpSession session, String filename) throws Exception {
    }

    public List<Task> getTaskByHostid(Integer hostId) throws Exception {
        return this.hostscanMapper.getTaskByHostid(hostId);
    }

    public List<Map<String, Object>> getSysResultByHostid(Integer id, Integer offset, Integer limit) throws Exception {
        return this.hostscanMapper.getSysResultByHostid(id, offset, limit);
    }

    public List<Map<String, Object>> getWebResultByHostid(Integer id) throws Exception {
        return this.hostscanMapper.getWebResultByHostid(id);
    }

    public List<Map<String, Object>> getDbResultByHostid(Integer id) throws Exception {
        return this.hostscanMapper.getDbResultByHostid(id);
    }

    public List<Map<String, Object>> getBlineResultByHostid(Integer id) throws Exception {
        return this.hostscanMapper.getBlineResultByHostid(id);
    }

    public Integer getDevCountByHostid(Integer hostId) throws Exception {
        return this.hostscanMapper.getDevCountByHostid(hostId);
    }

    public List<Map<String, Object>> getTypeByHostid(Integer hostId) throws Exception {
        return this.hostscanMapper.getTypeByHostid(hostId);
    }

    public void stop(Integer devid) throws Exception {
        Map<String, Object> device = this.taskBaseMapper.getTaskDevById(devid);
        int status = ObjectUtil.getInt(device.get("status"), 0);
        if (status == 1) {
            throw new UEException("正在扫描中...");
        }
        Integer type = ObjectUtil.getInt(device.get("type"));
        switch (type.intValue()) {
            case 0:
                throw new UEException("主机资产资产无需停止");
            case 1:
                this.webService.stop(devid, ObjectUtil.getInt(device.get("taskId")));
                return;
            case 2:
                throw new UEException("数据库资产资产无需停止");
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 11:
                throw new UEException("基线资产资产无需停止");
            case 9:
            case 10:
            default:
                return;
        }
    }

    public void stopScanTask(Integer taskId) throws Exception {
        List<Task> tasks = this.hostscanMapper.getTaskByHostid(taskId);
        for (Task t : tasks) {
            switch (t.getTaskType().intValue()) {
                case 0:
                    this.webService.stopScanTask(t.getId());
                    break;
                case 1:
                    this.taskService.stop(t.getId());
                    break;
                case 2:
                    throw new UEException("基线任务资产无需停止");
                case 4:
                    throw new UEException("数据库任务资产无需停止");
            }
        }
    }

    public Integer getSysCountByHostid(Integer id) throws Exception {
        return this.hostscanMapper.getSysCountByHostid(id);
    }
}
